(TeX-add-style-hook
 "REFERENCES"
 (lambda ()
   (LaTeX-add-bibitems
    "lubridate"
    "francq2011asymptotic"
    "boswijk1996unit"
    "boshnakov2012pld"
    "boshnakov2012mep"
    "boshnakov2009pcme"
    "HipelMcLeod"
    "LancTism"
    "FransesB1"
    "FransesB2"
    "McL93"
    "Mcleod1993parsimony"
    "McLeod1994diagnostic"
    "McLeod1995diagnosticCorrection"
    "b:Luleo94"
    "b:Varna92"
    "Sophie2005pacf"
    "Sophie2000par"
    "Pagano1978"
    "Rpackage2011pcme"))
 :bibtex)

